==> 1.0.0.tar.gz: android/src/main/java/io/hackle/hackle/HackleAppWrapper.java <==
package io.hackle.hackle;

import static io.hackle.hackle.Constants.Argument.EVENT;
import static io.hackle.hackle.Constants.Argument.EXPERIMENT_KEY;
import static io.hackle.hackle.Constants.Argument.FEATURE_KEY;
import static io.hackle.hackle.Constants.Argument.HACKLE_CONFIG;
import static io.hackle.hackle.Constants.Argument.REMOTE_CONFIG_DEFAULT_VALUE;
import static io.hackle.hackle.Constants.Argument.REMOTE_CONFIG_KEY;
import static io.hackle.hackle.Constants.Argument.SDK_KEY;
import static io.hackle.hackle.Constants.Argument.USER;

import android.content.Context;

import java.util.HashMap;

import io.hackle.android.HackleApp;

public class HackleAppWrapper {
    private final ArgumentParser argumentParser = new ArgumentParser();
    private final ModelConverter modelConverter = new ModelConverter();
    private final Context context;

    HackleAppWrapper(Context context) {
        this.context = context;
    }

    public void initialize(Object arguments, Runnable onReady) {
        final String sdkKey = argumentParser.getStringArgument(SDK_KEY, arguments);
        final HashMap<String, Object> hackleConfig = argumentParser.getHashMapArgument(HACKLE_CONFIG, arguments);

        if (hackleConfig.isEmpty()) {
            HackleApp.initializeApp(context, sdkKey, onReady);
        } else {
            HackleApp.initializeApp(context, sdkKey, modelConverter.convertHashMapToHackleConfig(hackleConfig), onReady);
        }
    }

    public String variation(Object arguments) {
        final int experimentKey = argumentParser.getIntArgument(EXPERIMENT_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().variation(experimentKey).toString();
        } else {
            return HackleApp.getInstance().variation(experimentKey, modelConverter.convertHashMapToUser(user)).toString();
        }
    }

    public HashMap<String, Object> variationDetail(Object arguments) {
        final int experimentKey = argumentParser.getIntArgument(EXPERIMENT_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return modelConverter.convertDecisionToHashMap(HackleApp.getInstance().variationDetail(experimentKey));
        } else {
            return modelConverter.convertDecisionToHashMap(HackleApp.getInstance().variationDetail(experimentKey, modelConverter.convertHashMapToUser(user)));
        }
    }


    public boolean isFeatureOn(Object arguments) {
        final int featureKey = argumentParser.getIntArgument(FEATURE_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().isFeatureOn(featureKey);
        } else {
            return HackleApp.getInstance().isFeatureOn(featureKey, modelConverter.convertHashMapToUser(user));
        }
    }

    public HashMap<String, Object> featureFlagDetail(Object arguments) {
        final int featureKey = argumentParser.getIntArgument(FEATURE_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return modelConverter.convertFeatureFlagDecisionToHashMap(HackleApp.getInstance().featureFlagDetail(featureKey));
        } else {
            return modelConverter.convertFeatureFlagDecisionToHashMap(HackleApp.getInstance().featureFlagDetail(featureKey, modelConverter.convertHashMapToUser(user)));
        }
    }

    public void track(Object arguments) {
        final HashMap<String, Object> event = argumentParser.getHashMapArgument(EVENT, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            HackleApp.getInstance().track(modelConverter.convertHashMapToEvent(event));
        } else {
            HackleApp.getInstance().track(modelConverter.convertHashMapToEvent(event), modelConverter.convertHashMapToUser(user));
        }
    }

    public String getDeviceId() {
        return HackleApp.getInstance().getDeviceId();
    }


    public Boolean remoteConfigGetBool(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final Boolean defaultValue = argumentParser.getBooleanArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getBoolean(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getBoolean(key, defaultValue);
        }
    }

    public Double remoteConfigGetDouble(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final Double defaultValue = argumentParser.getDoubleArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getDouble(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getDouble(key, defaultValue);
        }
    }

    public int remoteConfigGetInt(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final int defaultValue = argumentParser.getIntArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getInt(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getInt(key, defaultValue);
        }
    }

    public String remoteConfigGetString(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final String defaultValue = argumentParser.getStringArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getString(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getString(key, defaultValue);
        }
    }
}

==> 1.0.1.tar.gz: android/src/main/java/io/hackle/hackle/HackleAppWrapper.java <==
package io.hackle.hackle;

import static io.hackle.hackle.Constants.Argument.EVENT;
import static io.hackle.hackle.Constants.Argument.EXPERIMENT_KEY;
import static io.hackle.hackle.Constants.Argument.FEATURE_KEY;
import static io.hackle.hackle.Constants.Argument.HACKLE_CONFIG;
import static io.hackle.hackle.Constants.Argument.REMOTE_CONFIG_DEFAULT_VALUE;
import static io.hackle.hackle.Constants.Argument.REMOTE_CONFIG_KEY;
import static io.hackle.hackle.Constants.Argument.SDK_KEY;
import static io.hackle.hackle.Constants.Argument.USER;
import static io.hackle.hackle.Constants.Argument.WRAPPER_NAME;
import static io.hackle.hackle.Constants.Argument.WRAPPER_VERSION;

import android.content.Context;

import java.util.HashMap;

import io.hackle.android.HackleApp;
import io.hackle.android.HackleConfig;

public class HackleAppWrapper {
    private final ArgumentParser argumentParser = new ArgumentParser();
    private final ModelConverter modelConverter = new ModelConverter();
    private final Context context;

    HackleAppWrapper(Context context) {
        this.context = context;
    }

    public void initialize(Object arguments, Runnable onReady) {
        final String sdkKey = argumentParser.getStringArgument(SDK_KEY, arguments);
        final String wrapperName = argumentParser.getStringArgument(WRAPPER_NAME, arguments);
        final String wrapperVersion = argumentParser.getStringArgument(WRAPPER_VERSION, arguments);
        final HashMap<String, Object> hackleConfig = argumentParser.getHashMapArgument(HACKLE_CONFIG, arguments);

        if (hackleConfig.isEmpty()) {
            HackleApp.initializeApp(context, sdkKey, getDefaultHackleConfig(wrapperName, wrapperVersion), onReady);
        } else {
            hackleConfig.put("$wrapperName", wrapperName);
            hackleConfig.put("$wrapperVersion", wrapperVersion);
            HackleApp.initializeApp(context, sdkKey, modelConverter.convertHashMapToHackleConfig(hackleConfig), onReady);
        }
    }

    public String variation(Object arguments) {
        final int experimentKey = argumentParser.getIntArgument(EXPERIMENT_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().variation(experimentKey).toString();
        } else {
            return HackleApp.getInstance().variation(experimentKey, modelConverter.convertHashMapToUser(user)).toString();
        }
    }

    public HashMap<String, Object> variationDetail(Object arguments) {
        final int experimentKey = argumentParser.getIntArgument(EXPERIMENT_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return modelConverter.convertDecisionToHashMap(HackleApp.getInstance().variationDetail(experimentKey));
        } else {
            return modelConverter.convertDecisionToHashMap(HackleApp.getInstance().variationDetail(experimentKey, modelConverter.convertHashMapToUser(user)));
        }
    }


    public boolean isFeatureOn(Object arguments) {
        final int featureKey = argumentParser.getIntArgument(FEATURE_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().isFeatureOn(featureKey);
        } else {
            return HackleApp.getInstance().isFeatureOn(featureKey, modelConverter.convertHashMapToUser(user));
        }
    }

    public HashMap<String, Object> featureFlagDetail(Object arguments) {
        final int featureKey = argumentParser.getIntArgument(FEATURE_KEY, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return modelConverter.convertFeatureFlagDecisionToHashMap(HackleApp.getInstance().featureFlagDetail(featureKey));
        } else {
            return modelConverter.convertFeatureFlagDecisionToHashMap(HackleApp.getInstance().featureFlagDetail(featureKey, modelConverter.convertHashMapToUser(user)));
        }
    }

    public void track(Object arguments) {
        final HashMap<String, Object> event = argumentParser.getHashMapArgument(EVENT, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            HackleApp.getInstance().track(modelConverter.convertHashMapToEvent(event));
        } else {
            HackleApp.getInstance().track(modelConverter.convertHashMapToEvent(event), modelConverter.convertHashMapToUser(user));
        }
    }

    public String getDeviceId() {
        return HackleApp.getInstance().getDeviceId();
    }


    public Boolean remoteConfigGetBool(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final Boolean defaultValue = argumentParser.getBooleanArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getBoolean(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getBoolean(key, defaultValue);
        }
    }

    public Double remoteConfigGetDouble(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final Double defaultValue = argumentParser.getDoubleArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getDouble(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getDouble(key, defaultValue);
        }
    }

    public int remoteConfigGetInt(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final int defaultValue = argumentParser.getIntArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getInt(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getInt(key, defaultValue);
        }
    }

    public String remoteConfigGetString(Object arguments) {
        final String key = argumentParser.getStringArgument(REMOTE_CONFIG_KEY, arguments);
        final String defaultValue = argumentParser.getStringArgument(REMOTE_CONFIG_DEFAULT_VALUE, arguments);
        final HashMap<String, Object> user = argumentParser.getHashMapArgument(USER, arguments);

        if (user.isEmpty()) {
            return HackleApp.getInstance().remoteConfig().getString(key, defaultValue);
        } else {
            return HackleApp.getInstance().remoteConfig(modelConverter.convertHashMapToUser(user)).getString(key, defaultValue);
        }
    }

    private HackleConfig getDefaultHackleConfig(String wrapperName, String wrapperVersion) {
        return HackleConfig.builder().add("$wrapper_name", wrapperName).add("$wrapper_version", wrapperVersion).build();
    }
}
